@@ -397,9 +397,9 @@ def generate_pdf(analysis_run):
 
 
 
-def generate_excel(analysis_run, orgId, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
+def generate_excel(analysis_run, orgId, client_name, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
     try:
-        excel_renderer = ExcelRenderer(analysis_run, orgId, excel_data, report_gen_start_time, report_gen_completed_time)
+        excel_renderer = ExcelRenderer(analysis_run, orgId, client_name, excel_data, report_gen_start_time, report_gen_completed_time)
         workbook = excel_renderer.render()
     except Exception as ex:
         raise ex
@@ -510,12 +510,12 @@ def delete_excel_file(source_path):
 
 
 #Generate excel file
-def generate_excel_file(run_id, orgId, report_gen_start_time, report_gen_completed_time):
+def generate_excel_file(run_id, orgId, client_name, report_gen_start_time, report_gen_completed_time):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
     reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
-    generate_excel(run_id, orgId, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
+    generate_excel(run_id, orgId, client_name, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
     # excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
     if storage_name == 's3':
         excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
@@ -691,6 +691,108 @@ def get_post_opsql_count_results(url, data, type):
 
     return resp
 
+########################### Tenant and Logo Information #########################
+def get_tenants(orgId):
+    url = BASE_API_URL + f'/api/v2/tenants/{orgId}/clients/minimal'
+    res = get_response(url, 'V2 Tenants')
+    logger.info('Get tenants API response is %s', res)
+    if res == None or not res.ok:
+        logger.error('Get tenants API is failed')
+    return res.json()
+
+
+def get_tenant_list(org_id, level, tenant_list):
+    tenant_id_list = []
+    if level == 'partner':
+        tenant_id_list.append(org_id)
+    elif level == 'all-clients':
+        tenants = get_tenants(org_id)
+        for tenant in tenants:
+            tenant_id_list.append(tenant['uniqueId'])
+    elif level == 'specific_clients':
+        for tenant in tenant_list:
+            tenant_id_list.append(tenant['uniqueId'])
+    else:
+        tenant_id_list.append(org_id)
+    return tenant_id_list
+
+
+    
+def prepare_tenant_list(form, parameters, all_clients=False):
+    tenant_id_list = []
+    if parameters is not None and len(parameters) > 0:
+        if 'client' in parameters and parameters['client'] is not None:
+            clients = parameters['client']
+            if clients == 'All Clients' or clients == 'All Client':
+                tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
+            else:
+                if isinstance(clients, list):
+                    tenant_id_list = clients
+                else:
+                    for i in clients.split(','):
+                        tenant_id_list.append(i)
+        else:
+            tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
+    else:
+        tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
+    return tenant_id_list
+
+
+
+def fetch_all_clients(tenant_id, context, all_clients):
+    tenant_id_list = []
+    if all_clients and context == 'partner':
+        context = 'all-clients'
+    tenant_id_list = get_tenant_list(tenant_id, context, None)
+    return tenant_id_list
+
+
+
+def get_tenant_info(tenant_id_list, keys):
+    tenant_info = []
+    for tenant_id in tenant_id_list:
+        info={}
+        url = BASE_API_URL + f'/tenancy/api/v7/tenants/{tenant_id}/getTenant'
+        res = get_response(url, f'V7 tenants, tenant id is : {tenant_id}')
+        if res == None or not res.ok:
+            logger.error('Get tenant info API is failed')
+            return tenant_info
+        else:
+            for key in keys:
+                info[key] = res.json()[key]
+            tenant_info.append({tenant_id: info})
+    return tenant_info
+
+
+
+def get_logo_path_url(id):
+    url = BASE_API_URL + f'/api/v2/tenants/{id}/customBranding?cascade=true'
+    res = get_response(url, f'V2 tenants logo, tenant id is : {id}')
+    if res == None or not res.ok:
+        logger.error('Get logo path url API is failed')
+        return ''
+    if ('logo' in res.json() and res.json()['logo']) and ('logoPath' in res.json()['logo'] and res.json()['logo']['logoPath']):
+        return res.json()['logo']['logoPath']
+    else:
+        logger.error('Get logo path url is empty')
+        return ''
+
+
+
+def get_app_logo(id, context, parameters):
+    if context == 'client':
+        return get_logo_path_url(id)
+    elif context == 'partner':
+        if parameters is not None and len(parameters) > 0:
+            if 'client' in parameters and parameters['client'] is not None:
+                clients = parameters['client']
+                if len(clients) == 1:
+                    #read client and return path
+                    return get_logo_path_url(clients)
+                elif (clients == 'All Clients' or clients == 'All Client') or len(clients) > 1:
+                    return get_logo_path_url(id)
+    return get_logo_path_url(id)
+
 
 def update_run_progress(tenant_id, run_id, percent, message):
     url = BASE_API_URL + f'/reporting/api/v3/tenants/{tenant_id}/runs/{run_id}'
